pub struct TraderId(/* private fields */);Expand description
Represents a valid trader ID.
Implementations
Sourceimpl TraderId
impl TraderId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new TraderId instance.
Must be correctly formatted with two valid strings either side of a hyphen. It is expected a trader ID is the abbreviated name of the trader with an order ID tag number separated by a hyphen.
Example: “TESTER-001”.
The reason for the numerical component of the ID is so that order and position IDs do not collide with those from another node instance.
Errors
Returns an error if:
valueis not a valid ASCII string.valuedoes not contain a hyphen ‘-’ separator.- Either the name or tag part (before/after the hyphen) is empty.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn get_tag(&self) -> &str
pub fn get_tag(&self) -> &str
Returns the numerical tag portion of the trader ID.
Panics
Panics if the internal ID string does not contain a ‘-’ separator.
Sourcepub fn is_external(&self) -> bool
pub fn is_external(&self) -> bool
Returns whether this trader ID is external.